Re: [INTERNALS-WIN] apc problems on win7-64bit
| From: | Gaetano Giunta | Date: | Mon, 05 Dec 2011 18:18:51 +0000 |
| Subject: | Re: [INTERNALS-WIN] apc problems on win7-64bit | ||
| References: | 1 2 3 | Groups: | php.internals.win |
| Request: | Send a blank email to internals-win+get-848@lists.php.net to get a copy of this message | ||
Gaetano Giunta <giunta.gaetano@gmail.com> wrote on 01/12/2011 13:46:
Pierre Joye <pierre.php@gmail.com> wrote on 01/12/2011 13:15:PS: I found out why I was getting response times above 1 second: by using "localhost" to connect to mysql, without having an explicit binding tie of that address to 127.0.0.1 in the hosts file, mysql took 1 second to connect... Otoh, I still have not found out why most eZ Publish files do not get included in the APC cache. Here's the link for download: http://share.ez.no/download-develop/downloads/ez-publish-community-project-2011.11 Bye Gaetanohi, There are two different questions here. On Thu, Dec 1, 2011 at 10:39 AM, Gaetano Giunta <giunta.gaetano@gmail.com> wrote:I tested apc with a simple helloworld.php script, and indeed there is some difference: from 2.21 1.94 msec per page, from 451 to 513 requests per second (using 1 concurrent clients). If you could try a standard eZ Publish install, that would be great!Hello all I'm using php 5.3.8 + apache 2.2.21 from apachelounge, and the latest APC from Pierre's builds (php_apc-3.1.8-dev+igbinary-1.1.2-dev-20110321-5.3-ts-vc9-x86.zip), on a win 7 pro 64 bit machine. I am testing perfs using eZ Publish, and I have a very strange behavior: when APC is enabled, only a few files seem to be cached (less than 20). When running the same app on linux, more than 120 files are cached. Also the time to execute a page does not decrease at all - running ab with a concurrency of 1, I get 1.2 secs per page.We see totally different numbers here, do you have some smaller cases to reproduce this problem? Or should I try using a std ezpublish install?
This is definitely not the case here. I thought it would not work, and disabled it only to see if it could help in troubleshooting my problem - and I was surprised to see the list of cached files using such diverse paths...I noticed when turning stat off, that the list of files in apc cache (as per apc.php) have conflicting pathnames: some are full paths, some relative, some use windows slashes, some unix slashes. Might this have an impact? (note: there is no stream wrapper usage in eZ afaik) Is this a known problem / did anyone else experience it? Shall I file a bug?Turning off stat works well only if an app is written for it, ban _once, use absolute paths, etc.Cheers,